plone.app.event
===============

Plone.app.event is the calendaring implementation for Plone. It provides Event
Content Types (Archetypes based as well as Dexterity Behaviors), Timezone
support, RFC5545 icalendar export, Recurrence support and a lot more.

The ATContentType and dexterity features are automatically enabled depending
on installed packages.


Compatibility
-------------

plone.app.event is tested with latest Plone 4.2 and Plone 4.3.


Installation
------------

See the installation documentation at: docs/installation.rst.


PLIP implementation
-------------------

This packages and the other listed in sources.cfg are part of the PLIP 10886.
See: http://dev.plone.org/plone/ticket/10886


Contributing
------------

- Report issues: https://github.com/plone/plone.app.event
- Write code and tests.


.. note::
  Please note, allowing pull requests require the signation of the contributor
  agreement.
